sample_test_fail_all_setup_20150203_185047

### sample_config2

Total tests | Passed | Failed | Skipped | Start time | End time | Execution time | Naarad
--- | --- | --- | --- | --- | --- | --- | ---
3 | 0 | 0 | 3 | 2015-02-03 18:51:23 | 2015-02-03 18:51:23 | 0.112092971802 sec | Report

###

Test Name | Result | Description
--- | --- | ---
test1 | Skipped | Test has no docstring :(
test0 | Skipped | Test has no docstring :(
test2 | Skipped | Test has no docstring :(

###

Config Key | Value
--- | ---
a | b
c | d
max_failures_per_suite_before_abort | 0